@@ -7,7 +7,7 @@ logging.basicConfig(
 )
 
 
-def handle_date(date: str, date_type='start') -> datetime.datetime:
+def handle_date(date: str, date_type='start') -> datetime:
     try:
         if len(date) == 0:
             date_data = None
